@@ -13,19 +13,17 @@ pub(crate) use base::BaseClient;
 pub use base::{APIError, APIErrorVariant, APIResponse};
 use calendar::CalendarClient;
 pub use calendar::{
-    CreateCalendarInput, DeleteCalendarInput, GetCalendarEventsInput, GetCalendarInput,
+    CreateCalendarInput, GetCalendarEventsInput, GetGoogleCalendars, GetOutlookCalendars,
     StopCalendarSyncInput, SyncCalendarInput, UpdateCalendarInput,
 };
 use event::CalendarEventClient;
-pub use event::{
-    CreateEventInput, DeleteEventInput, GetEventInput, GetEventsInstancesInput, UpdateEventInput,
-};
+pub use event::{CreateEventInput, GetEventsInstancesInput, UpdateEventInput};
 pub use nettu_scheduler_api_structs::dtos::*;
 pub use nettu_scheduler_api_structs::send_event_reminders::AccountRemindersDTO as AccountReminders;
 pub use nettu_scheduler_domain::{
     providers::google::*, providers::outlook::*, scheduling::RoundRobinAlgorithm, BusyCalendar,
-    CalendarEventReminder, IntegrationProvider, RRuleOptions, ScheduleRule,
-    ServiceMultiPersonOptions, SyncedCalendar, TimePlan, ID, Metadata
+    CalendarEventReminder, IntegrationProvider, Metadata, RRuleOptions, ScheduleRule,
+    ServiceMultiPersonOptions, SyncedCalendar, TimePlan, ID,
 };
 use schedule::ScheduleClient;
 pub use schedule::{CreateScheduleInput, UpdateScheduleInput};
@@ -39,7 +37,9 @@ pub use shared::{KVMetadata, MetadataFindInput};
 use status::StatusClient;
 use std::sync::Arc;
 use user::UserClient;
-pub use user::{CreateUserInput, GetUserFreeBusyInput, UpdateUserInput};
+pub use user::{
+    CreateUserInput, GetUserFreeBusyInput, OAuthInput, RemoveUserIntegrationInput, UpdateUserInput,
+};
 
 // Domain
 pub use nettu_scheduler_api_structs::dtos::AccountDTO as Account;
@@ -54,6 +54,9 @@ pub use nettu_scheduler_api_structs::dtos::ServiceResourceDTO as ServiceResource
 pub use nettu_scheduler_api_structs::dtos::ServiceWithUsersDTO as Service;
 pub use nettu_scheduler_api_structs::dtos::UserDTO as User;
 
+pub use nettu_scheduler_domain::Tz;
+pub use nettu_scheduler_domain::Weekday;
+
 /// Nettu Scheduler Server SDK
 ///
 /// The SDK contains methods for interacting with the Nettu Scheduler server
@@ -80,7 +83,7 @@ impl NettuSDK {
         let schedule = ScheduleClient::new(base.clone());
         let service = ServiceClient::new(base.clone());
         let status = StatusClient::new(base.clone());
-        let user = UserClient::new(base.clone());
+        let user = UserClient::new(base);
 
         Self {
             account,
